@@ -1,9 +1,7 @@
-from typing import Sequence
-
-from pydb3.generator.select import SelectGenerator
-from pydb3.generator.update import UpdateGenerator
-from pydb3.generator.delete import DeleteGenerator
-from pydb3.generator.insert import InsertGenerator
+from pydb3.sql.generator.delete import DeleteGenerator
+from pydb3.sql.generator.insert import InsertGenerator
+from pydb3.sql.generator.select import SelectGenerator
+from pydb3.sql.generator.update import UpdateGenerator
 from pydb3.model import Model
 
 
@@ -46,4 +44,6 @@ class Db:
 
 
 if __name__ == '__main__':
-    pass
+    db = Db('mysql', host='localhost', port='3306', user='root', database='db', password='123456')
+    sql = db.select('student').join('class', id='stu_id').sql
+    print(sql)
