@@ -1,13 +1,14 @@
 class Blob:
     type = "blob"
 
-    def __init__(self, null=False, comment=None):
+    def __init__(self, null=False, comment=None, unique=False):
         self.length = None
         self.default = None
         self.null = null
         self.primary = False
         self.comment = comment
         self.auto = False
+        self.unique = unique
         self._value = None
 
     def __len__(self):
