@@ -4,17 +4,18 @@ from datetime import date
 class Date:
     type = "date"
 
-    def __init__(self, length=11, default=None, null=False, auto=True, primary=False, comment=None):
-        self.length = length
+    def __init__(self, default=None, null=False, auto=True, primary=False, comment=None, unique=False):
+        self.length = None
         self.default = default
         self.null = null
         self.primary = primary
         self.comment = comment
         self.auto = auto
+        self.unique = unique
         self._value = date.today()
 
     def __len__(self):
-        return self.length
+        return 10
 
     def __set__(self, instance, value):
         if not value and self.auto:
