@@ -15,6 +15,8 @@ class Image(Blob):
     type = 'image'
 
     def __set__(self, instance, value):
+        if isinstance(value, bytes):
+            value = value.decode("utf-8")
         if "path=" in value:
             value = value.split('path=')[-1]
             save_image(self._value, value)
